@@ -3,24 +3,24 @@ Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 import re
-from cfnlint.rules import CloudFormationLintRule
-from cfnlint.rules import RuleMatch
+
 import cfnlint.helpers
+from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
 
 class DynamicReferenceSecureString(CloudFormationLintRule):
     """Check if Dynamic Reference Secure Strings are only used in the correct locations"""
 
-    id = 'E1027'
-    shortdesc = 'Check dynamic references secure strings are in supported locations'
+    id = "E1027"
+    shortdesc = "Check dynamic references secure strings are in supported locations"
     description = (
-        'Dynamic References Secure Strings are only supported for a small set of resource properties.  '
-        'Validate that they are being used in the correct location when checking values '
-        'and Fn::Sub in resource properties. Currently doesn\'t check outputs, maps, conditions, '
-        'parameters, and descriptions.'
+        "Dynamic References Secure Strings are only supported for a small set of resource properties.  "
+        "Validate that they are being used in the correct location when checking values "
+        "and Fn::Sub in resource properties. Currently doesn't check outputs, maps, conditions, "
+        "parameters, and descriptions."
     )
-    source_url = 'https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html'
-    tags = ['functions', 'dynamic reference']
+    source_url = "https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html"
+    tags = ["functions", "dynamic reference"]
 
     def __init__(self):
         """Init"""
@@ -28,24 +28,24 @@ class DynamicReferenceSecureString(CloudFormationLintRule):
         self.property_specs = []
         self.resource_specs = []
         self.exceptions = {
-            'AWS::DirectoryService::MicrosoftAD': 'Password',
-            'AWS::DirectoryService::SimpleAD': 'Password',
-            'AWS::ElastiCache::ReplicationGroup': 'AuthToken',
-            'AWS::IAM::User.LoginProfile': 'Password',
-            'AWS::KinesisFirehose::DeliveryStream.RedshiftDestinationConfiguration': 'Password',
-            'AWS::OpsWorks::App.Source': 'Password',
-            'AWS::OpsWorks::Stack.RdsDbInstance': 'DbPassword',
-            'AWS::OpsWorks::Stack.Source': 'Password',
-            'AWS::RDS::DBCluster': 'MasterUserPassword',
-            'AWS::RDS::DBInstance': 'MasterUserPassword',
-            'AWS::Redshift::Cluster': 'MasterUserPassword',
+            "AWS::DirectoryService::MicrosoftAD": "Password",
+            "AWS::DirectoryService::SimpleAD": "Password",
+            "AWS::ElastiCache::ReplicationGroup": "AuthToken",
+            "AWS::IAM::User.LoginProfile": "Password",
+            "AWS::KinesisFirehose::DeliveryStream.RedshiftDestinationConfiguration": "Password",
+            "AWS::OpsWorks::App.Source": "Password",
+            "AWS::OpsWorks::Stack.RdsDbInstance": "DbPassword",
+            "AWS::OpsWorks::Stack.Source": "Password",
+            "AWS::RDS::DBCluster": "MasterUserPassword",
+            "AWS::RDS::DBInstance": "MasterUserPassword",
+            "AWS::Redshift::Cluster": "MasterUserPassword",
         }
 
     def initialize(self, cfn):
         """Init"""
         specs = cfnlint.helpers.RESOURCE_SPECS.get(cfn.regions[0])
-        self.property_specs = specs.get('PropertyTypes')
-        self.resource_specs = specs.get('ResourceTypes')
+        self.property_specs = specs.get("PropertyTypes")
+        self.resource_specs = specs.get("ResourceTypes")
         for resource_spec in self.resource_specs:
             self.resource_property_types.append(resource_spec)
         for property_spec in self.property_specs:
@@ -65,8 +65,8 @@ class DynamicReferenceSecureString(CloudFormationLintRule):
     def check_value(self, value, path, **kwargs):
         """Check Value"""
         matches = []
-        item_type = kwargs.get('item_type', {})
-        if item_type in ['Map']:
+        item_type = kwargs.get("item_type", {})
+        if item_type in ["Map"]:
             if isinstance(value, dict):
                 for map_key, map_value in value.items():
                     if not isinstance(map_value, dict):
@@ -100,11 +100,11 @@ class DynamicReferenceSecureString(CloudFormationLintRule):
                 if property_type in self.exceptions:
                     if prop == self.exceptions.get(property_type):
                         continue
-                primitive_type = specs.get(prop).get('PrimitiveType')
+                primitive_type = specs.get(prop).get("PrimitiveType")
                 if not primitive_type:
-                    primitive_type = specs.get(prop).get('PrimitiveItemType')
-                if specs.get(prop).get('Type') in ['List', 'Map']:
-                    item_type = specs.get(prop).get('Type')
+                    primitive_type = specs.get(prop).get("PrimitiveItemType")
+                if specs.get(prop).get("Type") in ["List", "Map"]:
+                    item_type = specs.get(prop).get("Type")
                 else:
                     item_type = None
                 if primitive_type:
@@ -126,9 +126,9 @@ class DynamicReferenceSecureString(CloudFormationLintRule):
         """Match for sub properties"""
         matches = []
 
-        if self.property_specs.get(property_type, {}).get('Properties'):
+        if self.property_specs.get(property_type, {}).get("Properties"):
             property_specs = self.property_specs.get(property_type, {}).get(
-                'Properties', {}
+                "Properties", {}
             )
             matches.extend(
                 self.check(cfn, properties, property_specs, property_type, path)
@@ -140,7 +140,7 @@ class DynamicReferenceSecureString(CloudFormationLintRule):
         """Check CloudFormation Properties"""
         matches = []
         resource_specs = self.resource_specs.get(resource_type, {}).get(
-            'Properties', {}
+            "Properties", {}
         )
         matches.extend(self.check(cfn, properties, resource_specs, resource_type, path))
 
